@@ -40,8 +40,8 @@
 
 #define DACT_VER_MAJOR 0
 #define DACT_VER_MINOR 8
-#define DACT_VER_REVISION 34
-#define DACT_VERSION "0.8.34"
+#define DACT_VER_REVISION 35
+#define DACT_VERSION "0.8.35"
 #ifdef DEBUG
 #define DACT_VER_SUB	"dev"
 #else
@@ -147,19 +147,14 @@ extern char dact_nonetwork;
 /* Win32 check here */
 
 
-#define SANITY(x, y...) { if ((x(y))<0) { PERROR(#x); return(-1); } }
 #ifdef DEBUG
-#define SHOWVAL(x...) { PRINT_LINE; fprintf(stderr, "dact: %s=%li\n", #x, (long) (x)); }
 #define SPOTVAR_NUM(x) { PRINT_LINE; fprintf(stderr, "dact: %s=%li\n", #x, (long) x); }
 #define SPOTVAR_STR(x) { PRINT_LINE; fprintf(stderr, "dact: %s=\"%s\"\n", #x, x); }
 #define CHECKPOINT PRINTERR("Checkpoint reached.")
-#define DPRINTF(x...) { PRINT_LINE; fprintf(stderr, x); fprintf(stderr, "\n"); }
 #else
-#define SHOWVAL(x...) x
 #define SPOTVAR_NUM(x) /**/
 #define SPOTVAR_STR(x) /**/
 #define CHECKPOINT /**/
-#define DPRINTF(x...) /**/
 #endif
 
 #ifndef DACT_FAILED_ALGO
